@@ -48,9 +48,9 @@ class BaseClient(metaclass=abc.ABCMeta):
     Parameters
     ----------
     name
-        The name of the actor.
+        The name of the client.
     version
-        The version of the actor.
+        The version of the client.
     loop
         The event loop. If `None`, the current event loop will be used.
     log_dir
@@ -85,7 +85,7 @@ class BaseClient(metaclass=abc.ABCMeta):
         self.version = version or "?"
 
         # Internally store the original configuration used to start the client.
-        self.config: Optional[Dict[str, Any]] = None
+        self.config: Dict[str, Any] = {}
 
     def __repr__(self):
         return f"<{str(self)} (name={self.name!r})>"
@@ -253,15 +253,25 @@ class BaseActor(BaseClient):
 
         super().__init__(*args, **kwargs)
 
-        self.validate_schema(schema)
+        self.load_schema(schema)
 
-    def validate_schema(self, schema: Union[SchemaType, None]) -> Union[Model, None]:
+    def load_schema(
+        self,
+        schema: Union[SchemaType, None],
+        is_file=True,
+    ) -> Union[Model, None]:
         """Loads and validates the actor schema."""
 
         if schema is None:
-            return None
+            schema = {
+                "$schema": "http://json-schema.org/draft-07/schema#",
+                "type": "object",
+                "properties": {},
+                "additionalProperties": True,
+            }
+            is_file = False
 
-        self.model = Model(self.name, schema, is_file=True, log=self.log)
+        self.model = Model(self.name, schema, is_file=is_file, log=self.log)
 
         return self.model
 
